@@ -2,7 +2,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-fnh.el
-;; Release:      $efs release: 1.17 $
+;; Release:      $efs release: 1.20pre2 $
 ;; Version:      #Revision: 1.4 $
 ;; RCS:
 ;; Description:  Look for the emacs version, and install into
@@ -18,7 +18,7 @@
 (provide 'efs-fnh)
 
 (defconst efs-fnh-version
-  (concat (substring "$efs release: 1.17 $" 14 -2)
+  (concat (substring "$efs release: 1.20pre2 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.4 $" 11 -2)))
 
