@@ -2,7 +2,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-kerberos.el
-;; Release:      $efs release: 1.19 $
+;; Release:      $efs release: 1.20pre2 $
 ;; Version:      #Revision: 1.1 $
 ;; RCS:
 ;; Description:  Support for Kerberos gateways.
@@ -19,7 +19,7 @@
 (require 'efs)
 
 (defconst efs-kerberos-version
-  (concat (substring "$efs release: 1.19 $" 14 -2)
+  (concat (substring "$efs release: 1.20pre2 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.1 $" 11 -2)))
 
